<template>
  <InfiniteLoading
    scrollViewClassName="common-page-infinite-scroll-list"
    v-bind="infiniteLoadingProps"
  >
    <template #renderItem="{ item }">
      <ResourceCard
        :title="item.title"
        :src="item.avatarUrl"
        :name="item.contact"
        :jobTitle="item.jobTitle"
        :time="item.lastShelfTime"
        :resourceCount="item.resourceCount"
        :intendedDeliveryCities="item.intendedDeliveryCities"
        :userId="item.userId"
        @click="handleClick(item)"
      >
      </ResourceCard>
    </template>
  </InfiniteLoading>
  <FloatButton text="我有订单" @click="goPublish" />
</template>

<script setup lang="ts">
import { useInfiniteLoading, useEvent } from '@12333/hooks';
import * as resourceServices from '@12333/services/api/Resource';
import { OrderInputType, IndustryCategoryType, OrderOperateBtnStatus } from '@12333/constants';
import { useAccessPersonalInfo, useCategoryMenu } from '@/hooks';
import { CategoryUtils } from '@12333/utils';
import Taro from '@tarojs/taro';

const queryState = reactive({
  categoryId: '',
});

const {
  ensureCategoryMenu,
  categoryMenuList: industryServicesCategoryList,
  categoryMenuRefetch,
} = useCategoryMenu({
  type: IndustryCategoryType.IndustryServices,
});

onMounted(async () => {
  await ensureCategoryMenu();
  queryState.categoryId = industryServicesCategoryList.value.find((x) =>
    CategoryUtils.isIHasResource(x.name)
  ).id;
});

useEvent('logout/refresh', async function (data) {
  try {
    console.log('resource');
    await categoryMenuRefetch();
    queryState.categoryId = industryServicesCategoryList.value.find((x) =>
      CategoryUtils.isIHasResource(x.name)
    ).id;
    infiniteLoadingProps.value.refetch();
  } catch (error) {}
});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFrontResourceListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          { property: 'isRecommend', order: OrderInputType.Desc },
          { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
    };

    return resourceServices.getFrontResourceList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['logout/refresh', 'resourceServices/getFrontResourceList', queryState],
    enabled: computed(() => !!queryState.categoryId),
  }
);

function handleClick(item: API.GetFrontResourceList) {
  Taro.navigateTo({
    url: `${RouterPath.resourceDetail}?id=${item.id}`,
  });
}

const goPublish = useAccessPersonalInfo(() => {
  Taro.navigateTo({
    url: `${RouterPath.publishOrder}?orderOperateBtnStatus=${OrderOperateBtnStatus.Add}`,
  });
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.resource-page-list {
  @include listScrollView;
  @include infiniteLoadingInTabBarPage;
}
</style>
